from asciidoc.blocks import table
import pytest


@pytest.mark.parametrize(
    "input,expected",
    (
        (None, (None, None)),
        ('', (None, None)),
        ('<', ('left', None)),
        ('^', ('center', None)),
        ('>', ('right', None)),
        ('.<', (None, 'top')),
        ('.^', (None, 'middle')),
        ('.>', (None, 'bottom')),
        ('<.<', ('left', 'top')),
        ('^.<', ('center', 'top')),
        ('>.<', ('right', 'top')),
        ('<.^', ('left', 'middle')),
        ('^.^', ('center', 'middle')),
        ('>.^', ('right', 'middle')),
        ('<.>', ('left', 'bottom')),
        ('^.>', ('center', 'bottom')),
        ('>.>', ('right', 'bottom')),
    )
)
def test_parse_align_spec(input, expected):
    assert table.parse_align_spec(input) == expected


@pytest.mark.parametrize(
    "input,expected",
    (
        (None, (1, 1)),
        ('', (1, 1)),
        ('0', (1, 1)),
        ('.0', (1, 1)),
        ('0.0', (1, 1)),
        ('2', (2, 1)),
        ('.2', (1, 2)),
        ('3.2', (3, 2)),
    )
)
def test_parse_table_span_spec(input, expected):
    assert table.parse_table_span_spec(input) == expected



"""asciidoc module"""

import sys
from .__metadata__ import VERSION, __version__

__all__ = ['VERSION', '__version__']

# If running as a script, we avoid these imports to avoid a circular
# RuntimeWarning, which is fine as we don't use them in that case.
if "-m" not in sys.argv:
    from .api import AsciiDocAPI
    from .asciidoc import execute, cli
    __all__ += ['AsciiDocAPI', 'execute', 'cli']
